package com.ff.game.service.impl;

import java.util.List;

import com.ff.base.constant.ConfigConstants;
import com.ff.base.utils.DateUtils;
import com.ff.game.api.request.GameUniqueDTO;
import com.ff.member.service.IMemberService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ff.game.mapper.GameMapper;
import com.ff.game.domain.Game;
import com.ff.game.service.IGameService;

import javax.annotation.Resource;

/**
 * 平台子游戏管理Service业务层处理
 *
 * @author shi
 * @date 2025-02-10
 */
@Service
public class GameServiceImpl implements IGameService
{
    @Autowired
    private GameMapper gameMapper;

    @Resource
    private IMemberService memberService;

    /**
     * 查询平台子游戏管理
     *
     * @param id 平台子游戏管理主键
     * @return 平台子游戏管理
     */
    @Override
    public Game selectGameById(Long id)
    {
        return gameMapper.selectGameById(id);
    }

    /**
     * 查询平台子游戏管理列表
     *
     * @param game 平台子游戏管理
     * @return 平台子游戏管理
     */
    @Override
    public List<Game> selectGameList(Game game)
    {
        return gameMapper.selectGameList(game);
    }

    /**
     * 新增平台子游戏管理
     *
     * @param game 平台子游戏管理
     * @return 结果
     */
    @Override
    public int insertGame(Game game)
    {
        game.setCreateTime(DateUtils.getNowDate());
        return gameMapper.insertGame(game);
    }

    /**
     * 修改平台子游戏管理
     *
     * @param game 平台子游戏管理
     * @return 结果
     */
    @Override
    public int updateGame(Game game)
    {
        game.setUpdateTime(DateUtils.getNowDate());
        return gameMapper.updateGame(game);
    }

    /**
     * 批量删除平台子游戏管理
     *
     * @param ids 需要删除的平台子游戏管理主键
     * @return 结果
     */
    @Override
    public int deleteGameByIds(Long[] ids)
    {
        return gameMapper.deleteGameByIds(ids);
    }

    /**
     * 删除平台子游戏管理信息
     *
     * @param id 平台子游戏管理主键
     * @return 结果
     */
    @Override
    public int deleteGameById(Long id)
    {
        return gameMapper.deleteGameById(id);
    }


    /**
     * 按平台id选择最大排序号
     *
     * @param platformId 平台id
     * @return {@link Integer }
     */
    @Override
    public Integer selectMaxSortNoByPlatformId(Long platformId) {
        return gameMapper.selectMaxSortNoByPlatformId(platformId);
    }



    /**
     * 选择游戏唯一列表
     *
     * @param gameUniqueDTO 游戏独有dto
     * @return {@link List }<{@link Game }>
     */
    @Override
    public List<Game> selectGameUniqueList(GameUniqueDTO gameUniqueDTO) {
        return gameMapper.selectGameUniqueList(gameUniqueDTO);
    }


}
