package com.ff.game.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ff.base.annotation.Log;
import com.ff.base.core.controller.BaseController;
import com.ff.base.core.domain.AjaxResult;
import com.ff.base.enums.BusinessType;
import com.ff.game.domain.Game;
import com.ff.game.service.IGameService;
import com.ff.base.utils.poi.ExcelUtil;
import com.ff.base.core.page.TableDataInfo;

/**
 * 平台子游戏管理Controller
 *
 * @author shi
 * @date 2025-02-10
 */
@RestController
@RequestMapping("/game/game")
public class GameController extends BaseController
{
    @Autowired
    private IGameService gameService;

    /**
     * 查询平台子游戏管理列表
     */
    @PreAuthorize("@ss.hasPermi('game:game:list')")
    @GetMapping("/list")
    public TableDataInfo list(Game game)
    {
        startPage();
        List<Game> list = gameService.selectGameList(game);
        return getDataTable(list);
    }

    /**
     * 导出平台子游戏管理列表
     */
    @PreAuthorize("@ss.hasPermi('game:game:export')")
    @Log(title = "平台子游戏管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Game game)
    {
        List<Game> list = gameService.selectGameList(game);
        ExcelUtil<Game> util = new ExcelUtil<Game>(Game.class);
        util.exportExcel(response, list, "平台子游戏管理数据");
    }

    /**
     * 获取平台子游戏管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('game:game:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gameService.selectGameById(id));
    }

    /**
     * 新增平台子游戏管理
     */
    @PreAuthorize("@ss.hasPermi('game:game:add')")
    @Log(title = "平台子游戏管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Game game)
    {
        return toAjax(gameService.insertGame(game));
    }

    /**
     * 修改平台子游戏管理
     */
    @PreAuthorize("@ss.hasPermi('game:game:edit')")
    @Log(title = "平台子游戏管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Game game)
    {
        return toAjax(gameService.updateGame(game));
    }

    /**
     * 删除平台子游戏管理
     */
    @PreAuthorize("@ss.hasPermi('game:game:remove')")
    @Log(title = "平台子游戏管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gameService.deleteGameByIds(ids));
    }
}
